@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.c,v 1.33 2003/11/25 18:19:23 fuyu Exp $
+ * $Id: bbs_thread_ui.c,v 1.35 2003/11/26 15:50:37 fuyu Exp $
  */
 
 #include "config.h"
@@ -1175,6 +1175,7 @@ start_thread_rendering(OchushaBBSThread *thread, const gchar *title,
 {
   RendererContext *context = (RendererContext *)user_data;
   BBSThreadView *view = context->view;
+  BBSThreadGUIInfo *info;
 
 #if DEBUG_GUI_MOST
   fprintf(stderr, "start_rendering\n");
@@ -1185,11 +1186,13 @@ start_thread_rendering(OchushaBBSThread *thread, const gchar *title,
   if (context->last_read_number == 0)
     {
       /* ɤॹξ祿ȥߤˤΤǤ˥ޡդ롣*/
-      BBSThreadGUIInfo *info = ensure_bbs_thread_info(context->thread);
+      info = ensure_bbs_thread_info(context->thread);
       info->last_read = bbs_thread_view_create_mark(view);
       info->next_mark = info->last_read;
       bbs_thread_view_scroll_to_mark(view, info->last_read);
     }
+  else
+    info = NULL;
 
   bbs_thread_view_push_tag(view, context->thread_title_tag);
 
@@ -1197,6 +1200,14 @@ start_thread_rendering(OchushaBBSThread *thread, const gchar *title,
   bbs_thread_view_append_text(view, "\n", 1);
 
   bbs_thread_view_pop_tags(view, context->thread_title_tag);
+
+  if (context->last_read_number == 0)
+    {
+      /* ɤॹξ祿ȥߤˤΤǤ˥ޡդ롣*/
+      g_assert(info != NULL);
+      bbs_thread_view_scroll_to_mark(view, info->last_read);
+    }
+
   gdk_threads_leave();
 
   return TRUE;	/* go ahead! */
@@ -1291,10 +1302,22 @@ render_response(OchushaBBSThread *thread, gint number,
       bbs_thread_view_pop_tags(view, context->response_name_tag);
       if (context->show_mailto_literally)
 	{
+	  char *tmp_mailto;
 	  bbs_thread_view_append_text(view, " [", 2);
-	  bbs_thread_view_append_text(view,
-				      (mailto != NULL
-				       ? mailto : _("broken here")), -1);
+
+	  if (mailto != NULL)
+	    tmp_mailto = simple_string_canon(mailto, -1, NULL, NULL);
+	  else
+	    tmp_mailto = NULL;
+
+	  if (tmp_mailto != NULL)
+	    {
+	      bbs_thread_view_append_text(view, tmp_mailto, -1);
+	      G_FREE(tmp_mailto);
+	    }
+	  else
+	    bbs_thread_view_append_text(view, _("broken here"), -1);
+
 	  bbs_thread_view_append_text(view, "]", 1);
 	}
 	    
@@ -1336,6 +1359,12 @@ render_response(OchushaBBSThread *thread, gint number,
 
   bbs_thread_view_append_text(view, "\n", 1);
 
+  if (number == context->last_read_number)
+    {
+      /* ɥ쥹*/
+      bbs_thread_view_scroll_to_mark(view, info->last_read);
+    }
+
   gdk_threads_leave();
 
   return TRUE;
