@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.h,v 1.9 2003/11/22 19:17:16 fuyu Exp $
+ * $Id: bbs_thread_ui.h,v 1.10 2003/11/25 18:19:23 fuyu Exp $
  */
 
 #ifndef _BBSTHREAD_UI_H_
@@ -103,6 +103,10 @@ void go_to_the_first_response(GtkWidget *widget, OchushaBBSThread *thread);
 void go_to_the_last_response(GtkWidget *widget, OchushaBBSThread *thread);
 void jump_to_new_comer_response(GtkWidget *widget, OchushaBBSThread *thread);
 
+void select_thread_view_font(OchushaApplication *application);
+void set_thread_view_font(const char *font_name);
+void reset_thread_view_font();
+void preview_thread_view_font(const char *font_name);
 
 #ifdef __cplusplus
 } // extern "C"
