@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.c,v 1.52 2003/11/26 04:13:26 fuyu Exp $
+ * $Id: bulletin_board_ui.c,v 1.54 2003/11/27 00:39:10 fuyu Exp $
  */
 
 #include "config.h"
@@ -70,6 +70,8 @@ static void toggle_mark_cb(ThreadlistView *view, OchushaBBSThread *thread,
 			   OchushaApplication *application);
 static void toggle_hide_cb(ThreadlistView *view, OchushaBBSThread *thread,
 			   OchushaApplication *application);
+static void reset_thread_cb(ThreadlistView *view, OchushaBBSThread *thread,
+			    OchushaApplication *application);
 static void copy_thread_url_cb(ThreadlistView *view, OchushaBBSThread *thread,
 			       OchushaApplication *application);
 static void mark_thread_cb(ThreadlistView *view, OchushaBBSThread *thread,
@@ -639,6 +641,8 @@ open_bulletin_board(OchushaApplication *application,
 		       G_CALLBACK(toggle_mark_cb), application);
       g_signal_connect(G_OBJECT(view), "toggle_hide",
 		       G_CALLBACK(toggle_hide_cb), application);
+      g_signal_connect(G_OBJECT(view), "reset_thread",
+		       G_CALLBACK(reset_thread_cb), application);
       g_signal_connect(G_OBJECT(view), "copy_thread_url",
 		       G_CALLBACK(copy_thread_url_cb), application);
       g_signal_connect(G_OBJECT(view), "mark_thread",
@@ -1248,13 +1252,26 @@ toggle_hide_cb(ThreadlistView *view, OchushaBBSThread *thread,
 {
   BBSThreadGUIInfo *info = ensure_bbs_thread_info(thread);
   info->view_flags ^= BBS_THREAD_HIDDEN;
+  if ((info->view_flags & BBS_THREAD_HIDDEN) != 0)
+    ochusha_bbs_thread_remove_cache(thread, &application->config);
+  update_threadlist_entry_style(application, view, thread);
+}
+
+
+static void
+reset_thread_cb(ThreadlistView *view, OchushaBBSThread *thread,
+		OchushaApplication *application)
+{
+  BBSThreadGUIInfo *info = ensure_bbs_thread_info(thread);
+  ochusha_bbs_thread_remove_cache(thread, &application->config);
+  info->view_flags = 0;
   update_threadlist_entry_style(application, view, thread);
 }
 
 
 static void
 copy_thread_url_cb(ThreadlistView *view, OchushaBBSThread *thread,
-	       OchushaApplication *application)
+		   OchushaApplication *application)
 {
   ochusha_clipboard_set_text(application, ochusha_bbs_thread_get_url(thread));
 }
