@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: paned_notebook.c,v 1.4 2003/11/07 14:27:06 fuyu Exp $
+ * $Id: paned_notebook.c,v 1.5 2003/11/26 10:05:26 fuyu Exp $
  */
 
 #include "config.h"
@@ -239,7 +239,7 @@ paned_notebook_class_init(PanedNotebookClass *klass)
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET(PanedNotebookClass, item_view_being_closed),
 		 NULL, NULL,
-		 ochusha_marshal_VOID__POINTER_POINTER,
+		 ochusha_marshal_VOID__POINTER_OBJECT,
 		 G_TYPE_NONE, 2,
 		 G_TYPE_POINTER,
 		 GTK_TYPE_WIDGET);
@@ -249,7 +249,7 @@ paned_notebook_class_init(PanedNotebookClass *klass)
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET(PanedNotebookClass, item_view_closed),
 		 NULL, NULL,
-		 ochusha_marshal_VOID__POINTER_POINTER,
+		 ochusha_marshal_VOID__POINTER_OBJECT,
 		 G_TYPE_NONE, 2,
 		 G_TYPE_POINTER,
 		 GTK_TYPE_WIDGET);
@@ -553,6 +553,14 @@ paned_notebook_set_paned_style(PanedNotebook *paned_notebook,
 	  paned->orientation = GTK_ORIENTATION_HORIZONTAL;
 	}
 
+      if (GDK_IS_WINDOW(paned->handle))
+	{
+	  GdkCursor *cursor = gdk_cursor_new_for_display(gtk_widget_get_display(GTK_WIDGET(paned)),
+							 paned->cursor_type);
+	  gdk_window_set_cursor(paned->handle, cursor);
+	  gdk_cursor_unref(cursor);
+	}
+
       if (GTK_WIDGET_VISIBLE(paned_notebook))
 	gtk_widget_queue_resize(GTK_WIDGET(paned_notebook));
     }
