@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_view.c,v 1.21 2003/11/23 22:39:35 fuyu Exp $
+ * $Id: threadlist_view.c,v 1.22 2003/11/26 10:04:16 fuyu Exp $
  */
 
 #include "config.h"
@@ -149,6 +149,7 @@ enum {
   TOGGLE_MARK_SIGNAL,
   TOGGLE_HIDE_SIGNAL,
   MARK_THREAD_SIGNAL,
+  RESET_THREAD_SIGNAL,
   COPY_THREAD_URL_SIGNAL,
   ADVANCE_VIEW_SIGNAL,
   BACK_VIEW_SIGNAL,
@@ -178,6 +179,7 @@ enum {
   POPUP_MENU_MARK_SELECTION,
   POPUP_MENU_UNMARK_SELECTION,
   POPUP_MENU_TOGGLE_HIDE_SELECTION,
+  POPUP_MENU_RESET_SELECTION,
   POPUP_MENU_COPY_THREAD_URL
 };
 
@@ -325,6 +327,20 @@ threadlist_view_class_init(ThreadlistViewClass *klass)
 	0,
 	"<Separator>"
       },
+      {
+	_("/Reset Selected Threads(_R)"),	/* menu path */
+	NULL,					/* accelerator */
+	popup_menu_callback,			/* callback_func */
+	POPUP_MENU_RESET_SELECTION,		/* act */
+	NULL					/* type */
+      },
+      {
+	_("/-------"),
+	NULL,
+	NULL,
+	0,
+	"<Separator>"
+      },
       {
 	_("/Copy Selected Thread's URL"),	/* menu path */
 	NULL,					/* accelerator */
@@ -372,18 +388,18 @@ threadlist_view_class_init(ThreadlistViewClass *klass)
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET(ThreadlistViewClass, thread_mouse_over),
 		 NULL, NULL,
-		 ochusha_marshal_VOID__POINTER,
+		 ochusha_marshal_VOID__OBJECT,
 		 G_TYPE_NONE, 1,
-		 G_TYPE_POINTER);
+		 OCHUSHA_TYPE_BBS_THREAD);
   threadlist_view_signals[THREAD_MOUSE_OUT_SIGNAL] =
     g_signal_new("thread_mouse_out",
 		 G_TYPE_FROM_CLASS(klass),
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET(ThreadlistViewClass, thread_mouse_out),
 		 NULL, NULL,
-		 ochusha_marshal_VOID__POINTER,
+		 ochusha_marshal_VOID__OBJECT,
 		 G_TYPE_NONE, 1,
-		 G_TYPE_POINTER);
+		 OCHUSHA_TYPE_BBS_THREAD);
 
   threadlist_view_signals[TOGGLE_MARK_SIGNAL] =
     g_signal_new("toggle_mark",
@@ -391,38 +407,47 @@ threadlist_view_class_init(ThreadlistViewClass *klass)
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET(ThreadlistViewClass, toggle_mark),
 		 NULL, NULL,
-		 ochusha_marshal_VOID__POINTER,
+		 ochusha_marshal_VOID__OBJECT,
 		 G_TYPE_NONE, 1,
-		 G_TYPE_POINTER);
+		 OCHUSHA_TYPE_BBS_THREAD);
   threadlist_view_signals[TOGGLE_HIDE_SIGNAL] =
     g_signal_new("toggle_hide",
 		 G_TYPE_FROM_CLASS(klass),
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET(ThreadlistViewClass, toggle_hide),
 		 NULL, NULL,
-		 ochusha_marshal_VOID__POINTER,
+		 ochusha_marshal_VOID__OBJECT,
 		 G_TYPE_NONE, 1,
-		 G_TYPE_POINTER);
-  /* ɥۥå᤮*/
-  threadlist_view_signals[COPY_THREAD_URL_SIGNAL] =
-    g_signal_new("copy_thread_url",
-		 G_TYPE_FROM_CLASS(klass),
-		 G_SIGNAL_RUN_LAST,
-		 G_STRUCT_OFFSET(ThreadlistViewClass, copy_thread_url),
-		 NULL, NULL,
-		 ochusha_marshal_VOID__POINTER,
-		 G_TYPE_NONE, 1,
-		 G_TYPE_POINTER);
+		 OCHUSHA_TYPE_BBS_THREAD);
   threadlist_view_signals[MARK_THREAD_SIGNAL] =
     g_signal_new("mark_thread",
 		 G_TYPE_FROM_CLASS(klass),
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET(ThreadlistViewClass, mark_thread),
 		 NULL, NULL,
-		 ochusha_marshal_VOID__POINTER_BOOLEAN,
+		 ochusha_marshal_VOID__OBJECT_BOOLEAN,
 		 G_TYPE_NONE, 2,
-		 G_TYPE_POINTER,
+		 OCHUSHA_TYPE_BBS_THREAD,
 		 G_TYPE_BOOLEAN);
+  /* ɥۥå᤮*/
+  threadlist_view_signals[RESET_THREAD_SIGNAL] =
+    g_signal_new("reset_thread",
+		 G_TYPE_FROM_CLASS(klass),
+		 G_SIGNAL_RUN_LAST,
+		 G_STRUCT_OFFSET(ThreadlistViewClass, reset_thread),
+		 NULL, NULL,
+		 ochusha_marshal_VOID__OBJECT,
+		 G_TYPE_NONE, 1,
+		 OCHUSHA_TYPE_BBS_THREAD);
+  threadlist_view_signals[COPY_THREAD_URL_SIGNAL] =
+    g_signal_new("copy_thread_url",
+		 G_TYPE_FROM_CLASS(klass),
+		 G_SIGNAL_RUN_LAST,
+		 G_STRUCT_OFFSET(ThreadlistViewClass, copy_thread_url),
+		 NULL, NULL,
+		 ochusha_marshal_VOID__OBJECT,
+		 G_TYPE_NONE, 1,
+		 OCHUSHA_TYPE_BBS_THREAD);
   threadlist_view_signals[ADVANCE_VIEW_SIGNAL] =
     g_signal_new("advance_view",
 		 G_TYPE_FROM_CLASS(klass),
@@ -477,6 +502,8 @@ threadlist_view_class_init(ThreadlistViewClass *klass)
 			       G_TYPE_INT, POPUP_MENU_OPEN_SELECTION);
   gtk_binding_entry_add_signal(binding_set, GDK_t, 0, "do_on_selection", 1,
 			       G_TYPE_INT, POPUP_MENU_OPEN_SELECTION_IN_TAB);
+  gtk_binding_entry_add_signal(binding_set, GDK_r, 0, "do_on_selection", 1,
+			       G_TYPE_INT, POPUP_MENU_RESET_SELECTION);
   gtk_binding_entry_add_signal(binding_set, GDK_asterisk, 0,
 			       "do_on_thread_at_cursor", 1,
 			       G_TYPE_INT, MARK_THREAD);
@@ -1143,6 +1170,13 @@ do_on_selection_helper(GtkTreeModel *model, GtkTreePath *path,
 		    thread);
       break;
 
+    case POPUP_MENU_RESET_SELECTION:
+      g_signal_emit(G_OBJECT(args->view),
+		    threadlist_view_signals[RESET_THREAD_SIGNAL],
+		    0,
+		    thread);
+      break;
+
     case POPUP_MENU_COPY_THREAD_URL:
       g_signal_emit(G_OBJECT(args->view),
 		    threadlist_view_signals[COPY_THREAD_URL_SIGNAL],
@@ -1966,7 +2000,7 @@ threadlist_view_open(ThreadlistView *view)
 			     G_TYPE_INT,	/* number of responses unread*/
 			     G_TYPE_INT,	/* rank difference */
 			     G_TYPE_LONG,	/* last modified */
-			     G_TYPE_POINTER);	/* data (OchushaBBSThread *) */
+			     OCHUSHA_TYPE_BBS_THREAD);	/* data */
 
   gtk_tree_view_set_model(&view->view, GTK_TREE_MODEL(store));
   view->model = GTK_TREE_MODEL(store);
