@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_network_broker.c,v 1.14 2003/11/26 06:02:14 fuyu Exp $
+ * $Id: ochusha_network_broker.c,v 1.16 2003/11/27 00:43:31 fuyu Exp $
  */
 
 #include "config.h"
@@ -60,6 +60,7 @@
 
 #define DISABLE_PERSISTENT_CONNECTION		0
 #define ENABLE_GZIPPED_DIFFERENCIAL_READ	0
+#define ENABLE_SIGNAL_BEFORE_SLEEP		1
 
 #define CACHE_COMPARE_SIZE	128	/* Ĥѹǽˤ٤ */
 #define HEADER_BUFFER_LENGTH	256
@@ -608,9 +609,15 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
       sock_fd = ghttp_get_socket(request);
       fprintf(stderr, "1: sock_fd=%d state=%d\n", sock_fd, state);
 #endif
+#if ENABLE_SIGNAL_BEFORE_SLEEP
+      if (!ochusha_async_buffer_signal(buffer,
+			"ochusha_network_broker.c: http_read_from_url()"))
+	state = ghttp_error;
+#else
       if (!ochusha_async_buffer_check_active(buffer,
 			"ochusha_network_broker.c: http_read_from_url()"))
 	state = ghttp_error;
+#endif
 
       if (state == ghttp_error || state == ghttp_done)
 	break;
@@ -752,20 +759,8 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 	ghttp_flush_response_buffer(request);
       else if (state == ghttp_error)
 	{
-#if 1
 	  error_message = _("Unknown I/O error.");
 	  goto error_exit;
-#else
-	  /* XXX:  */
-	  status_code = ghttp_status_code(request);
-
-	  if (status_code != 200)
-	    {
-	      error_message = _("Unknown I/O error.");
-	      goto error_exit;
-	    }
-	  state = ghttp_done;
-#endif
 	}
 
       body = ghttp_get_body(request);
@@ -1186,8 +1181,13 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
       while (TRUE)
 	{
 	  state = ghttp_process(request);
+#if ENABLE_SIGNAL_BEFORE_SLEEP
+	  if (!ochusha_async_buffer_signal(buffer,
+			"ochusha_network_broker.c: try_update_cache()"))
+#else
 	  if (!ochusha_async_buffer_check_active(buffer,
 			"ochusha_network_broker.c: try_update_cache()"))
+#endif
 	    {
 	      g_signal_emit(G_OBJECT(args->broker),
 			    broker_signals[ACCESS_TERMINATED_SIGNAL],
