@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_2ch.c,v 1.28 2003/11/25 18:20:44 fuyu Exp $
+ * $Id: ochusha_thread_2ch.c,v 1.30 2003/11/26 15:05:55 fuyu Exp $
  */
 
 #include "config.h"
@@ -330,7 +330,7 @@ ochusha_thread_2ch_check_url(OchushaBBSThread *thread, const char *url,
 	  board_id, thread_id);
 #endif
   if (strcmp(ochusha_bulletin_board_get_id(thread->board), board_id) == 0
-      && strcmp(thread->id, thread_id) == 0)
+      && thread_id != NULL && strcmp(thread->id, thread_id) == 0)
     result = TRUE;
   else
     result = FALSE;
@@ -350,11 +350,20 @@ ochusha_thread_2ch_remove_cache(OchushaBBSThread *thread,
 				OchushaConfig *config)
 {
   const char *dat_url;
+  OchushaThread2ch *thread_2ch;
   g_return_if_fail(OCHUSHA_IS_THREAD_2CH(thread) && config != NULL);
 
-  dat_url = ochusha_thread_2ch_get_dat_url(OCHUSHA_THREAD_2CH(thread));
+  thread_2ch = OCHUSHA_THREAD_2CH(thread);
+
+  dat_url = ochusha_thread_2ch_get_dat_url(thread_2ch);
   if (dat_url != NULL)
     ochusha_config_cache_unlink_file(config, dat_url);
+
+  if (thread_2ch->last_modified != NULL)
+    {
+      G_FREE(thread_2ch->last_modified);
+      thread_2ch->last_modified = NULL;
+    }
 }
 
 
